.. _irradiance_classes:

irradiance
----------

The irradiance sub-package of pvfactors implements all irradiance related models and methods that can be applied to pvfactors PV array objects.

base
^^^^

.. automodule:: pvfactors.irradiance.base
   :no-members:
   :no-inherited-members:
   :noindex:

.. autosummary::
   :toctree: generated/
   :nosignatures:

   ~pvfactors.irradiance.base.BaseModel


models
^^^^^^

.. automodule:: pvfactors.irradiance.models
   :no-members:
   :no-inherited-members:
   :noindex:

.. autosummary::
   :toctree: generated/
   :nosignatures:

   ~pvfactors.irradiance.models.IsotropicOrdered
   ~pvfactors.irradiance.models.HybridPerezOrdered
